Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(3401)

Unified Diff: build/android/pylib/gtest/test_package.py

Issue 19479002: [Android] Clean up gtest filtering logic. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Addressed all comments Created 7 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « build/android/pylib/gtest/dispatch.py ('k') | build/android/pylib/gtest/test_runner.py » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: build/android/pylib/gtest/test_package.py
diff --git a/build/android/pylib/gtest/test_package.py b/build/android/pylib/gtest/test_package.py
index 4846322f39415fd0194ddb19a60560f8a70a341f..4cccea104c7fc48854fa071995debc432c965948 100644
--- a/build/android/pylib/gtest/test_package.py
+++ b/build/android/pylib/gtest/test_package.py
@@ -61,14 +61,11 @@ class TestPackage(object):
"""Install the test package to the device."""
raise NotImplementedError('Method must be overriden.')
- def GetDisabledPrefixes(self):
- return ['DISABLED_', 'FLAKY_', 'FAILS_']
-
- def _ParseGTestListTests(self, all_tests):
- """Parses and filters the raw test lists.
+ def _ParseGTestListTests(self, raw_list):
+ """Parses a raw test list as provided by --gtest_list_tests.
Args:
all_tests: The raw test listing with the following format:
IPCChannelTest.
SendMessageInChannelConnected
@@ -77,14 +74,14 @@ class TestPackage(object):
DISABLED_SendWithTimeoutMixedOKAndTimeout
Returns:
- A list of non-disabled tests. For the above raw listing:
+ A list of all tests. For the above raw listing:
- [IPCChannelTest.SendMessageInChannelConnected, IPCSyncChannelTest.Simple]
+ [IPCChannelTest.SendMessageInChannelConnected, IPCSyncChannelTest.Simple,
+ IPCSyncChannelTest.DISABLED_SendWithTimeoutMixedOKAndTimeout]
"""
ret = []
current = ''
- disabled_prefixes = self.GetDisabledPrefixes()
- for test in all_tests:
+ for test in raw_list:
if not test:
continue
if test[0] != ' ' and not test.endswith('.'):
@@ -96,6 +93,5 @@ class TestPackage(object):
if 'YOU HAVE' in test:
break
test_name = test[2:]
- if not any([test_name.startswith(x) for x in disabled_prefixes]):
- ret += [current + test_name]
+ ret += [current + test_name]
return ret
« no previous file with comments | « build/android/pylib/gtest/dispatch.py ('k') | build/android/pylib/gtest/test_runner.py » ('j') | no next file with comments »
@@ -61,14 +61,11 @@ class TestPackage(object):
Args:
- all_tests: The raw test listing with the following format:
+ raw_list: The raw test listing with the following format:
IPCChannelTest.
SendMessageInChannelConnected

Powered by Google App Engine
This is Rietveld 408576698